==> A.i386-pc-linux-suse8.2.tar.gz: A.i386-pc-linux-suse8.2/amd/sun_map_parse.h <==
/* A Bison parser, made from /home/ezk/proj/amd/am-utils-exp/A.i386-pc-linux-suse8.2/amd/../../amd/sun_map_parse.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_SUN_MAP_PARSE_H
# define BISON_SUN_MAP_PARSE_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum sun_map_tokentype {
     NEWLINE = 258,
     COMMENT = 259,
     WSPACE = 260,
     WORD = 261
   };
#endif
#define NEWLINE 258
#define COMMENT 259
#define WSPACE 260
#define WORD 261




#ifndef YYSTYPE
#line 85 "sun_map_parse.y"
typedef union {
  char strval[2048];
} sun_map_stype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 56 "sun_map_parse.h"
# define YYSTYPE sun_map_stype
#endif

extern YYSTYPE sun_map_lval;


#endif /* not BISON_SUN_MAP_PARSE_H */

==> A.i386-pc-linux-suse9.2.tar.gz: A.i386-pc-linux-suse9.2/amd/sun_map_parse.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum sun_map_tokentype {
     NEWLINE = 258,
     COMMENT = 259,
     WSPACE = 260,
     WORD = 261
   };
#endif
#define NEWLINE 258
#define COMMENT 259
#define WSPACE 260
#define WORD 261




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 83 "sun_map_parse.y"
typedef union YYSTYPE {
  char strval[2048];
} YYSTYPE;
/* Line 1318 of yacc.c.  */
#line 53 "sun_map_parse.h"
# define sun_map_stype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE sun_map_lval;
